References
----------

.. [Bergen20] Bergen *et al.* (2020),
   *Generalizing RNA velocity to transient cell states through dynamical modeling*,
   `Nature Biotech <https://doi.org/10.1038/s41587-020-0591-3>`__.

.. [Manno18] La Manno *et al.* (2018),
   *RNA velocity of single cells*,
   `Nature <https://doi.org/10.1038/s41586-018-0414-6>`__.

.. [Wolf18] Wolf *et al.* (2018),
   *Scanpy: large-scale single-cell gene expression data analysis*,
   `Genome Biology <https://doi.org/10.1186/s13059-017-1382-0>`__.

.. [Wolf19] Wolf *et al.* (2019),
   *PAGA: graph abstraction reconciles clustering with trajectory inference*,
   `Genome Biology <https://doi.org/10.1186/s13059-019-1663-x>`__.
